diff --git a/exercises/038_structs2.zig b/exercises/038_structs2.zig
index af7eb1f..b9d84aa 100644
--- a/exercises/038_structs2.zig
+++ b/exercises/038_structs2.zig
@@ -8,7 +8,7 @@
 //
 const std = @import("std");
 
-const Class = enum {
+const Role = enum {
     wizard,
     thief,
     bard,
@@ -16,7 +16,7 @@ const Class = enum {
 };
 
 const Character = struct {
-    class: Class,
+    role: Role,
     gold: u32,
     health: u8,
     experience: u32,
@@ -27,7 +27,7 @@ pub fn main() void {
 
     // Glorp the Wise
     chars[0] = Character{
-        .class = Class.wizard,
+        .role = Role.wizard,
         .gold = 20,
         .health = 100,
         .experience = 10,
@@ -35,7 +35,7 @@ pub fn main() void {
 
     // Please add "Zump the Loud" with the following properties:
     //
-    //     class      bard
+    //     role       bard
     //     gold       10
     //     health     100
     //     experience 20
diff --git a/patches/patches/038_structs2.patch b/patches/patches/038_structs2.patch
index 5d0d188..7d85de0 100644
--- a/patches/patches/038_structs2.patch
+++ b/patches/patches/038_structs2.patch
@@ -1,6 +1,6 @@
 44a45,50
 >     chars[1] = Character{
->         .class = Class.bard,
+>         .role = Role.bard,
 >         .gold = 10,
 >         .health = 100,
 >         .experience = 20,
diff --git a/exercises/037_structs.zig b/exercises/037_structs.zig
index 32f7b41..c345faf 100644
--- a/exercises/037_structs.zig
+++ b/exercises/037_structs.zig
@@ -22,8 +22,8 @@
 //
 const std = @import("std");
 
-// We'll use an enum to specify the character class.
-const Class = enum {
+// We'll use an enum to specify the character role.
+const Role = enum {
     wizard,
     thief,
     bard,
@@ -33,7 +33,7 @@ const Class = enum {
 // Please add a new property to this struct called "health" and make
 // it a u8 integer type.
 const Character = struct {
-    class: Class,
+    role: Role,
     gold: u32,
     experience: u32,
 };
@@ -41,7 +41,7 @@ const Character = struct {
 pub fn main() void {
     // Please initialize Glorp with 100 health.
     var glorp_the_wise = Character{
-        .class = Class.wizard,
+        .role = Role.wizard,
         .gold = 20,
         .experience = 10,
     };